utils

package
v0.0.0-...-ac7002b Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 20, 2026 License: Apache-2.0 Imports: 14 Imported by: 0

Documentation

Overview

Package utils provides utility functions for the CLI including secure password handling.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func GetAllProblems

func GetAllProblems() []problems.Interface

GetAllProblems -> returns all problems

func GetAllVariants

func GetAllVariants() []variants.Interface

GetAllVariants -> returns all variants

func GetProblemByName

func GetProblemByName(name string) (problems.Interface, error)

GetProblemByName -> returns the problem function of the given name

func GetVariantByName

func GetVariantByName(name string) (variants.Interface, error)

GetVariantByName -> returns the variant function of the given name

func ReadPassword

func ReadPassword(prompt string) (string, error)

ReadPassword prompts for a password with the given prompt message and reads it securely. The password input is hidden from the terminal (no echo).

func ReadPasswordWithConfirmation

func ReadPasswordWithConfirmation(prompt, confirmPrompt string) (string, error)

ReadPasswordWithConfirmation prompts for password twice to confirm.

Types

This section is empty.

Jump to