Documentation
¶
Overview ¶
Package utils provides utility functions for the CLI including secure password handling.
Index ¶
- func GetAllProblems() []problems.Interface
- func GetAllVariants() []variants.Interface
- func GetProblemByName(name string) (problems.Interface, error)
- func GetVariantByName(name string) (variants.Interface, error)
- func ReadPassword(prompt string) (string, error)
- func ReadPasswordWithConfirmation(prompt, confirmPrompt string) (string, error)
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GetAllProblems ¶
GetAllProblems -> returns all problems
func GetAllVariants ¶
GetAllVariants -> returns all variants
func GetProblemByName ¶
GetProblemByName -> returns the problem function of the given name
func GetVariantByName ¶
GetVariantByName -> returns the variant function of the given name
func ReadPassword ¶
ReadPassword prompts for a password with the given prompt message and reads it securely. The password input is hidden from the terminal (no echo).
func ReadPasswordWithConfirmation ¶
ReadPasswordWithConfirmation prompts for password twice to confirm.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.